@@ -2,18 +2,18 @@
 
 import re
 import os.path
-from typing import Any, Iterable
+from typing import Any, Iterable, Union
 
 from cerberus import Validator
 
 from alidistlint.common import Error, YAMLFilePart, TrackedLocationLoader, \
     position_of_key
 
-ValidationErrors = list[str | dict[Any, 'ValidationErrors']]
-ValidationErrorTree = str | dict[Any, ValidationErrors] | ValidationErrors
+ValidationErrors = list[Union[str, dict[Any, 'ValidationErrors']]]
+ValidationErrorTree = Union[str, dict[Any, ValidationErrors], ValidationErrors]
 """An error tree as produced by cerberus."""
 
-ObjectPath = tuple[str | int, ...]
+ObjectPath = tuple[Union[str, int], ...]
 """Specifies where in a nested object a value is located as a series of keys.
 
 For instance, A is at path (0, "a") in the object [{"a": A}].
@@ -26,7 +26,9 @@ def get_schema_for_file(file_name: str) -> dict:
         basename = os.path.basename(file_name)
         if not isinstance(value, str):
             error(field, 'must be a string')
-        elif f'{value.lower()}.sh' != basename:
+        elif basename != '<stdin>' and f'{value.lower()}.sh' != basename:
+            # If basename is '<stdin>', we probably got '-' as an input file,
+            # i.e. stdin. In that case we don't know the original file name.
             error(field, f'must match the file name {basename!r} '
                   'case-insensitively, excluding the .sh')
 
@@ -179,7 +181,8 @@ def emit_validation_errors(error_tree: ValidationErrorTree,
     """Parse any validation errors from a cerberus validator."""
     if isinstance(error_tree, dict):
         for key, suberrors in error_tree.items():
-            if re.fullmatch(r'(all|any|none|one)of definition [0-9]+', key):
+            if isinstance(key, str) and \
+               re.fullmatch(r'(all|any|none|one)of definition [0-9]+', key):
                 subpath = path
             else:
                 subpath = path + (key,)
