@@ -7,7 +7,11 @@ import sys
 import tempfile
 from typing import NoReturn
 
-from alidistlint import common, yamllint, shellcheck, headerlint
+from alidistlint import common, __version__
+from alidistlint.headerlint import headerlint
+from alidistlint.scriptlint import scriptlint
+from alidistlint.yamllint import yamllint
+from alidistlint.shellcheck import shellcheck
 
 
 def run_with_args(args: Namespace) -> int:
@@ -16,11 +20,13 @@ def run_with_args(args: Namespace) -> int:
     progname = os.path.basename(sys.argv[0])
     have_error = False
     with tempfile.TemporaryDirectory(prefix=progname) as tempdir:
-        headers, scripts = common.split_files(tempdir, args.recipes)
+        errors, headers, scripts = common.split_files(tempdir, args.recipes)
         errors = itertools.chain(
-            () if args.no_headerlint else headerlint.headerlint(headers),
-            () if args.no_yamllint else yamllint.yamllint(headers),
-            () if args.no_shellcheck else shellcheck.shellcheck(scripts),
+            errors,
+            () if args.no_headerlint else headerlint(headers),
+            () if args.no_scriptlint else scriptlint(scripts),
+            () if args.no_yamllint else yamllint(headers),
+            () if args.no_shellcheck else shellcheck(scripts),
         )
         for error in errors:
             print(formatter(error))
@@ -35,10 +41,13 @@ def parse_args() -> Namespace:
     selected. If any messages with "error" severity were produced,
     `alidistlint` exits with a non-zero exit code.
     ''')
+    parser.add_argument('--version', action='version', version=__version__)
     parser.add_argument('-S', '--no-shellcheck', action='store_true',
-                        help="don't run shellcheck on the main script")
+                        help="don't run shellcheck on each script")
+    parser.add_argument('-L', '--no-scriptlint', action='store_true',
+                        help="don't run internal linter on each script")
     parser.add_argument('-Y', '--no-yamllint', action='store_true',
-                        help="don't run yamllint on the header")
+                        help="don't run yamllint on the YAML header")
     parser.add_argument('-H', '--no-headerlint', action='store_true',
                         help="don't run internal linter on the YAML header")
     parser.add_argument('-f', '--format', metavar='FORMAT',
